pub(crate) fn main() -> Result<()>Expand description
Main entry point for the application.
This function initializes the server and routes for the application.
It spawns the zombie death monitor as a background task that runs until the program terminates.
It also creates the necessary directories for file uploads.